@@ -286,27 +286,30 @@ class Parameters:
                                     f"{e.__class__} {e}")
 
         par = Parameters(
-                length_day=data["length_day"],
-                plength_day=data["plength_day"],
-                initial_inf=data["initial_inf"],
-                static_play_at_home=data["static_play_at_home"],
-                dyn_play_at_home=data["dyn_play_at_home"],
-                data_dist_cutoff=data["data_dist_cutoff"],
-                dyn_dist_cutoff=data["dyn_dist_cutoff"],
-                play_to_work=data["play_to_work"],
-                work_to_play=data["work_to_play"],
-                local_vaccination_thresh=data["local_vaccination_threshold"],
-                global_detection_thresh=data["global_detection_threshold"],
-                daily_ward_vaccination_capacity=data[
-                                "daily_ward_vaccination_capacity"],
-                neighbour_weight_threshold=data["neighbour_weight_threshold"],
-                daily_imports=data["daily_imports"],
-                UV=data["UV"],
-                _name=data["name"],
-                _authors=data["author(s)"],
-                _version=data["version"],
-                _contacts=data["contact(s)"],
-                _references=data["reference(s)"],
+                length_day=data.get("length_day", 0.7),
+                plength_day=data.get("plength_day", 0.5),
+                initial_inf=data.get("initial_inf", 0),
+                static_play_at_home=data.get("static_play_at_home", 0.0),
+                dyn_play_at_home=data.get("dyn_play_at_home", 0.0),
+                data_dist_cutoff=data.get("data_dist_cutoff", 10000000.0),
+                dyn_dist_cutoff=data.get("dyn_dist_cutoff", 10000000.0),
+                play_to_work=data.get("play_to_work", 0.0),
+                work_to_play=data.get("work_to_play", 0.0),
+                local_vaccination_thresh=data.get(
+                                    "local_vaccination_threshold", 4),
+                global_detection_thresh=data.get(
+                                    "global_detection_threshold", 4),
+                daily_ward_vaccination_capacity=data.get(
+                                "daily_ward_vaccination_capacity", 5),
+                neighbour_weight_threshold=data.get(
+                                "neighbour_weight_threshold", 0.0),
+                daily_imports=data.get("daily_imports", 0),
+                UV=data.get("UV", 0.0),
+                _name=data.get("name", parameters),
+                _authors=data.get("author(s)", "unknown"),
+                _version=data.get("version", "unknown"),
+                _contacts=data.get("contact(s)", "unknown"),
+                _references=data.get("reference(s)", "none"),
                 _filename=json_file,
                 _repository=repository,
                 _repository_dir=repository_dir,
